/*
 * MZViewer - A viewer for MZData format Mass Spectra
 * Copyright (c) 2005 Simon Andrews

 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */
package uk.ac.bbsrc.babraham.mzdata;

import java.util.Arrays;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Vector;

import uk.ac.bbsrc.babraham.mzdata.exceptions.MZCollectionException;

/**
 * @author andrewss
 *
 */
public class MZCollection {
    
    private String sampleName;
    private MZSpectrum [] spectra = null;
    private int currentSpectraPosition = 0;
    
    public void setSampleName (String name) {
        sampleName = name;
    }

    public String getSampleName () {
        return sampleName;
    }
    
    public void setSpectrumCount (int i) throws MZCollectionException {
        if (spectra != null) {
            throw new MZCollectionException ("setSpectrumCount can only be called once per collection");
        }
        else {
            spectra = new MZSpectrum [i];
        }
    }
    
    public void addSpectrum (MZSpectrum spectrum) throws MZCollectionException {

        if (spectra == null) {
            throw new MZCollectionException("setSpectrumCount must be called before adding any spectra");
        }
        
        if (currentSpectraPosition == spectra.length) {
            throw new MZCollectionException("Spectrum count was set at "+spectra.length+" and these many spectra have already been added");
        }
        
        spectra[currentSpectraPosition] = spectrum;
        
        ++currentSpectraPosition;
    }
    
    public int getSpectrumCount () {
        return spectra.length;
    }
    
    public void checkSpecturmCount () throws MZCollectionException {
    		for (int i=0;i<spectra.length;i++) {
    			if (spectra[i] == null) {
    				throw new MZCollectionException ("Found no spectrum at position "+(i+1));
    			}
    		}
    }
    
    public MZSpectrum getSpectrumAt (int i) {
        return spectra[i];
    }
    
    public MZSpectrum getSpectrumWithID (int i) {
        for (int j=0;j<spectra.length;j++) {
            if (spectra[j]!=null) {
                if (spectra[j].getID() == i) {
                    return spectra[j];
                }
            }
        }
        return null;
    }
    
    public int [] getMSLevels () {
    		Hashtable h = new Hashtable();
    		for (int i=0;i<spectra.length;i++) {
                if (h.containsKey(new Integer(spectra[i].getMsLevel()))) {
                    h.put(new Integer(spectra[i].getMsLevel()),new Integer(2));                    
                }
                else {
                    h.put(new Integer(spectra[i].getMsLevel()),new Integer(1));
                }
    		}

            // Now take out any msLevels with only one value (as you can't make
            // a chromatogram with only 1 spectrum)
            Enumeration e = h.keys();
            while (e.hasMoreElements()) {
                Object o = e.nextElement();
                if (((Integer)h.get(o)).intValue() == 1) {
                    h.remove(o);
                }
            }
            
    		Integer [] integers = (Integer [])(h.keySet().toArray(new Integer [0]));
    		
    		Arrays.sort(integers);
    		
    		int [] msLevels = new int [integers.length];
    		
    		for (int i=0;i<integers.length;i++) {
    			msLevels[i] = integers[i].intValue();
    		}
    		
    		return msLevels;
    }
    
    public MZSpectrum [] getSpectraForMSLevel (int level) {
    		Vector v = new Vector();
    		for (int i=0;i<spectra.length;i++) {
    			if (spectra[i].getMsLevel()==level) {
    				v.add(spectra[i]);
    			}
    		}
    		MZSpectrum [] returnList = (MZSpectrum [])v.toArray(new MZSpectrum[0]);
    		Arrays.sort(returnList);
    		return returnList;
    }
}
