/*
 * MZViewer - A viewer for MZData format Mass Spectra
 * Copyright (c) 2005 Simon Andrews

 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */
package uk.ac.bbsrc.babraham.mzdata.displays;

import java.awt.Component;

import javax.swing.*;

/**
 * @author Andrewss
 *
 */
public class LoadProgressDisplay extends JDialog implements LoadProgressListener, Runnable {
	
	private int count;
	private int total;
	private JLabel label;
	private Thread t;
	private boolean loadComplete = false;
	
	public LoadProgressDisplay (Component parent) {
		t = new Thread(this);
		setTitle("Loading data...");
		count = 0;
		total = 0;
		label = new JLabel("Loaded 0 spectra",JLabel.CENTER);
		getContentPane().add(label);
		setSize(250,75);
		setLocationRelativeTo(parent);
		setModal(true);
		t.start();
	}

	public void updateLoadCount(int count, int total) {
		this.count = count;
		this.total = total;
		t.interrupt();
	}
	
	public void loadComplete () {
		setVisible(false);
		dispose();
	}
	
	public void loadError (Exception e) {
		setVisible(false);
		JOptionPane.showMessageDialog(this,e.getMessage(),"Error",JOptionPane.ERROR_MESSAGE);
		dispose();
	}

	public void run() {
		while(!loadComplete) {
			label.setText("Loaded "+count+" of "+total+" spectra");
			this.validate();
			try {
				Thread.sleep(1000);
			} catch (InterruptedException e) {
			}
		}
	}

}
